@@ -1,562 +1,525 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="es">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="es" version="2.1">
 <context>
     <name>defaultlook</name>
     <message>
-        <location filename="../defaultlook.ui" line="20"/>
-        <location filename="../defaultlook.cpp" line="55"/>
-        <location filename="../defaultlook.cpp" line="467"/>
-        <location filename="../defaultlook.cpp" line="474"/>
-        <location filename="../defaultlook.cpp" line="491"/>
-        <location filename="../defaultlook.cpp" line="502"/>
-        <location filename="../defaultlook.cpp" line="512"/>
+        <location filename="defaultlook.ui" line="20"/>
+        <location filename="defaultlook.cpp" line="52"/>
+        <location filename="defaultlook.cpp" line="464"/>
+        <location filename="defaultlook.cpp" line="471"/>
+        <location filename="defaultlook.cpp" line="488"/>
+        <location filename="defaultlook.cpp" line="499"/>
+        <location filename="defaultlook.cpp" line="509"/>
         <source>MX Tweak</source>
         <translation>MX Tweak</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="54"/>
+        <location filename="defaultlook.ui" line="54"/>
         <source>Xfce Settings</source>
         <translation>Xfce Ajustes</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="63"/>
+        <location filename="defaultlook.ui" line="63"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the panel&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Personalizar el panel&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="77"/>
-        <location filename="../defaultlook.ui" line="283"/>
+        <location filename="defaultlook.ui" line="77"/>
+        <location filename="defaultlook.ui" line="283"/>
         <source>Panel</source>
         <translation>Panel</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="97"/>
+        <location filename="defaultlook.ui" line="97"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Configure window behavior and shortcuts&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Configurar comportamiento de ventana y atajos&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="111"/>
+        <location filename="defaultlook.ui" line="111"/>
         <source>Window Manager</source>
         <translation>Gestor de ventanas</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="131"/>
+        <location filename="defaultlook.ui" line="131"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the look of your desktop&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Personalizar la aparencia del escritorio&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="145"/>
+        <location filename="defaultlook.ui" line="145"/>
         <source>Appearance</source>
         <translation>Aparencia</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="223"/>
+        <location filename="defaultlook.ui" line="223"/>
         <source>About</source>
         <translation>Acerca de</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="234"/>
+        <location filename="defaultlook.ui" line="234"/>
         <source>Help</source>
         <translation>Ayuda</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="251"/>
+        <location filename="defaultlook.ui" line="251"/>
         <source>Quit application</source>
         <translation>Terminar aplicación</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="254"/>
+        <location filename="defaultlook.ui" line="254"/>
         <source>Close</source>
         <translation>Cerrar</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="261"/>
+        <location filename="defaultlook.ui" line="261"/>
         <source>Alt+N</source>
         <translation>Alt+N</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="291"/>
+        <location filename="defaultlook.ui" line="291"/>
         <source>Options</source>
         <translation>Opciones</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="311"/>
+        <location filename="defaultlook.ui" line="311"/>
         <source>Backup current panel configuration</source>
         <translation>Respaldar configuración del panel actual</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="318"/>
+        <location filename="defaultlook.ui" line="318"/>
         <source>Restore backup panel configuration</source>
         <translation>Restaurar configuración del panel de respaldo</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="325"/>
+        <location filename="defaultlook.ui" line="325"/>
         <source>Restore default panel</source>
         <translation>Restablecer panel por defecto</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="338"/>
+        <location filename="defaultlook.ui" line="338"/>
         <source>Affects 1st panel</source>
         <translation>Afecta el 1er panel</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="345"/>
+        <location filename="defaultlook.ui" line="345"/>
         <source>Display panel vertically</source>
         <translation>Desplegar panel vertical</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="365"/>
+        <location filename="defaultlook.ui" line="359"/>
         <source>Bottom</source>
         <translation>Fondo</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="370"/>
+        <location filename="defaultlook.ui" line="364"/>
         <source>Top</source>
         <translation>Arriba</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="378"/>
+        <location filename="defaultlook.ui" line="372"/>
         <source>Display panel horizontally</source>
         <translation>Desplegar panel horizontalmente</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="398"/>
+        <location filename="defaultlook.ui" line="386"/>
         <source>Left</source>
         <translation>Izquierda</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="403"/>
+        <location filename="defaultlook.ui" line="391"/>
         <source>Right</source>
         <translation>Derecha</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="411"/>
+        <location filename="defaultlook.ui" line="399"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Affects all panels&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Afecta todos los paneless&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="431"/>
+        <location filename="defaultlook.ui" line="419"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Buttons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Botones de ventanas&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="446"/>
-        <location filename="../defaultlook.ui" line="549"/>
-        <location filename="../defaultlook.ui" line="741"/>
-        <location filename="../defaultlook.ui" line="860"/>
-        <location filename="../defaultlook.ui" line="902"/>
+        <location filename="defaultlook.ui" line="434"/>
+        <location filename="defaultlook.ui" line="537"/>
+        <location filename="defaultlook.ui" line="707"/>
+        <location filename="defaultlook.ui" line="826"/>
+        <location filename="defaultlook.ui" line="868"/>
         <source>Apply</source>
         <translation>Aplicar</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="469"/>
+        <location filename="defaultlook.ui" line="457"/>
         <source>Theme</source>
         <translation>Tema</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="483"/>
+        <location filename="defaultlook.ui" line="471"/>
         <source>Theme Options</source>
         <translation>Opciones de Tema</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="513"/>
+        <location filename="defaultlook.ui" line="501"/>
         <source>Fix some website fields when using dark theme</source>
         <translation>Corregir campos en páginas web cuando usa el tema oscuro</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="516"/>
+        <location filename="defaultlook.ui" line="504"/>
         <source>Firefox dark theme tweak</source>
         <translation>Retocar tema oscuro de Firefox</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="523"/>
+        <location filename="defaultlook.ui" line="511"/>
         <source>Fix HexChat input box in dark theme</source>
         <translation>Ajuste el cuadro de entrada HexChat a tema oscura</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="575"/>
+        <location filename="defaultlook.ui" line="563"/>
         <source>Undo</source>
         <translation>Deshacer</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="582"/>
+        <location filename="defaultlook.ui" line="570"/>
         <source>Preview</source>
         <translation>Vista previa</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="589"/>
-        <source>Remove User Theme Sets</source>
-        <translation>Eliminar conjuntos de temas de usuario</translation>
-    </message>
-    <message>
-        <location filename="../defaultlook.ui" line="600"/>
-        <source>Save Current Settings as a Theme Set</source>
-        <translation>Guardar la configuración actual como un conjunto de temas</translation>
-    </message>
-    <message>
-        <location filename="../defaultlook.ui" line="614"/>
-        <location filename="../defaultlook.ui" line="707"/>
+        <location filename="defaultlook.ui" line="580"/>
+        <location filename="defaultlook.ui" line="673"/>
         <source>Compositor</source>
         <translation>Compositor</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="635"/>
+        <location filename="defaultlook.ui" line="601"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor Settings&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Ajustes del Compositor Xfce&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="638"/>
+        <location filename="defaultlook.ui" line="604"/>
         <source>Xfwm Settings</source>
         <translation>Xfwm Ajustes</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="662"/>
+        <location filename="defaultlook.ui" line="628"/>
         <source>None</source>
         <translation>Ninguno</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="667"/>
+        <location filename="defaultlook.ui" line="633"/>
         <source>Xfwm (Xfce) Compositor</source>
         <translation>Xfwm (Xfce) Compositor</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="672"/>
+        <location filename="defaultlook.ui" line="638"/>
         <source>Compton </source>
         <translation>Compton </translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="680"/>
+        <location filename="defaultlook.ui" line="646"/>
         <source>Edit compton.conf directly in text editor</source>
         <translation>Editar compton.conf directamente en editor de texto</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="683"/>
+        <location filename="defaultlook.ui" line="649"/>
         <source>Edit compton.conf</source>
         <translation>Editar compton.conf</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="714"/>
+        <location filename="defaultlook.ui" line="680"/>
         <source>Transparency and shadow options</source>
         <translation>Opciones de transparencias y sombras</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="721"/>
+        <location filename="defaultlook.ui" line="687"/>
         <source>Launch compton-conf configuration tool</source>
         <translation>Lanzar herramienta de configuración compton-conf</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="724"/>
+        <location filename="defaultlook.ui" line="690"/>
         <source>Compton settings</source>
         <translation>Ajustes Compton</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="777"/>
+        <location filename="defaultlook.ui" line="743"/>
         <source>Config Options</source>
         <translation>Opciones para configurar</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="785"/>
+        <location filename="defaultlook.ui" line="751"/>
         <source>Reset Lightdm (login screen) to system default theme</source>
-        <translation>Restablecer Lightdm (pantalla de inicio) a la tema predeterminada</translation>
+        <translation>Restablecer Lightdm (pantalla de inicio) a la tema predeterminado</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="792"/>
+        <location filename="defaultlook.ui" line="758"/>
         <source>Reset Thunar custom right-click actions to system defaults</source>
         <translation>Reestablecer las acciones personalizados de Thunar a los predeterminados</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="799"/>
+        <location filename="defaultlook.ui" line="765"/>
         <source>Use intel driver instead of default &quot;modsetting&quot; driver (requires restart)</source>
         <translation>Usa controlador intel en vez del predeterminado controlador &apos;modesetting&apos; (se requiere reiniciar) </translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="806"/>
+        <location filename="defaultlook.ui" line="772"/>
         <source>          NOTE: existing /etc/X11/xorg.conf.d/20-intel.conf will be backed up to home folder</source>
         <translation>NOTA: el actual /etc/X11/xorg.conf.d/20-intel.conf será respaldado en la carpeta /home</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="813"/>
+        <location filename="defaultlook.ui" line="779"/>
         <source>Use tearfree amdgpu option</source>
-        <translation>Use la opción tearfree amdgpu</translation>
+        <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="820"/>
+        <location filename="defaultlook.ui" line="786"/>
         <source>          NOTE: existing /etc/X11/xorg.conf.d/20-amd.conf will be backed up to home folder</source>
-        <translation>NOTA: el actual /etc/X11/xorg.conf.d/20-amd.conf será respaldado en la carpeta home</translation>
+        <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="827"/>
+        <location filename="defaultlook.ui" line="793"/>
         <source>Use tearfree radeon driver option</source>
-        <translation>Use la opción tearfree del controlador radeon</translation>
+        <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="834"/>
+        <location filename="defaultlook.ui" line="800"/>
         <source>          NOTE: existing /etc/X11/xorg.conf.d/20-radeon.conf will be backed up to home folder</source>
-        <translation>NOTA: el actual /etc/X11/xorg.conf.d/20-radeon.conf será respaldado en la carpeta home</translation>
+        <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="874"/>
+        <location filename="defaultlook.ui" line="840"/>
         <source>Other</source>
         <translation>Otro</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="882"/>
+        <location filename="defaultlook.ui" line="848"/>
         <source>Enable single-click on desktop</source>
         <translation>Habilitar un solo clik en el escritorio</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="889"/>
+        <location filename="defaultlook.ui" line="855"/>
         <source>Enable single-click in Thunar File Manager</source>
-        <translation>Habilitar un solo clik en el gestor de archivos Thunar</translation>
+        <translation>Habilitar un solo clik en Thunar gestor de archivos</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="926"/>
+        <location filename="defaultlook.ui" line="892"/>
         <source>Show systray (notification area) frame</source>
-        <translation>Mostrar marco en el área de notificación</translation>
+        <translation>Mostrar marco de systray (área de notificación)</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="933"/>
+        <location filename="defaultlook.ui" line="899"/>
         <source>Show windows from all workspaces in panel</source>
-        <translation>Mostrar ventanas de todas las áreas de trabajo en el panel</translation>
+        <translation>Mostrar ventanas de todos los áreas de trabajos en el panel</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="940"/>
+        <location filename="defaultlook.ui" line="906"/>
         <source>Enable mounting of internal drives by non-root users</source>
         <translation>Habilitar montar discos internos por usuarios no-root</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="947"/>
+        <location filename="defaultlook.ui" line="913"/>
         <source>Disable shortening of long filenames on the desktop</source>
         <translation>Deshabilitar acortar nombres largos de archivos en el escritorio</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="954"/>
+        <location filename="defaultlook.ui" line="920"/>
         <source>Enable hibernate on Log Out menu </source>
         <translation>Habilitar Hibernar en el menú de Salida</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="961"/>
+        <location filename="defaultlook.ui" line="927"/>
         <source>                   note: to hibernate, swap needs to be &gt;= RAM</source>
         <translation>                   nota: para hibernar, el swap debe ser &gt;= RAM</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="466"/>
+        <location filename="defaultlook.cpp" line="463"/>
         <source>About MX Tweak</source>
         <translation>Acerca de MX Ajustes</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="467"/>
+        <location filename="defaultlook.cpp" line="464"/>
         <source>Version: </source>
         <translation>Versión:</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="468"/>
+        <location filename="defaultlook.cpp" line="465"/>
         <source>App for quick default ui theme changes and tweaks</source>
         <translation>Ap para cambios rápidos al tema de la IU por defecto y ajustes</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="470"/>
+        <location filename="defaultlook.cpp" line="467"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Copyright (c) MX Linux</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="471"/>
-        <location filename="../defaultlook.cpp" line="474"/>
+        <location filename="defaultlook.cpp" line="468"/>
+        <location filename="defaultlook.cpp" line="471"/>
         <source>License</source>
         <translation>Licencia</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="472"/>
+        <location filename="defaultlook.cpp" line="469"/>
         <source>Cancel</source>
         <translation>Cancelar</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="503"/>
+        <location filename="defaultlook.cpp" line="500"/>
         <source>Finished! Firefox may require a restart for changes to take effect</source>
         <translation>¡Listo! Firefox puede requerir un reinicio para que los cambios surtan efecto. </translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="513"/>
+        <location filename="defaultlook.cpp" line="510"/>
         <source>This app is Xfce-only</source>
         <translation>Esta aplicación es solamente para Xfce</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="655"/>
+        <location filename="defaultlook.cpp" line="652"/>
         <source>Panel settings</source>
         <translation>Ajustes del panel</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="656"/>
-        <source>Your current panel settings have been backed up in a hidden folder called .restore in your home folder (~/.restore/)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
+        <location filename="defaultlook.cpp" line="653"/>
         <source> Your current panel settings have been backed up in a hidden folder called .restore in your home folder (~/.restore/)</source>
-        <translation type="vanished"> Su configuración del panel se ha respaldado en una carpeta oculta llamada .restore en su folder home (~/.restore/)</translation>
+        <translation> Su configuración del panel se ha respaldado en una carpeta oculta llamada .restore en su folder home (~/.restore/)</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="1073"/>
+        <location filename="defaultlook.cpp" line="1070"/>
         <source>Choose a theme set</source>
         <translation>Escoger un juego de tema</translation>
     </message>
 </context>
-<context>
-    <name>remove_user_theme_set</name>
-    <message>
-        <location filename="../remove_user_theme_set.ui" line="14"/>
-        <source>Remove User Theme Set</source>
-        <translation>Eliminar el conjunto de temas de usuario</translation>
-    </message>
-</context>
-<context>
-    <name>theming_to_tweak</name>
-    <message>
-        <location filename="../theming_to_tweak.ui" line="14"/>
-        <source>Dialog</source>
-        <translation>Diálogo</translation>
-    </message>
-    <message>
-        <location filename="../theming_to_tweak.ui" line="20"/>
-        <source>Enter name for new theme set</source>
-        <translation>Introduzca el nombre para el nuevo conjunto de temas</translation>
-    </message>
-</context>
 <context>
     <name>window_buttons</name>
     <message>
-        <location filename="../window_buttons.ui" line="14"/>
-        <location filename="../window_buttons.cpp" line="36"/>
+        <location filename="window_buttons.ui" line="14"/>
+        <location filename="window_buttons.cpp" line="36"/>
         <source>Window Buttons</source>
         <translation>Botones de ventanas</translation>
     </message>
     <message>
-        <location filename="../window_buttons.ui" line="28"/>
+        <location filename="window_buttons.ui" line="28"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Appearance&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Apariencia&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="../window_buttons.ui" line="35"/>
+        <location filename="window_buttons.ui" line="35"/>
         <source>Show button labels</source>
         <translation>Mostrar etiquetas de los botones</translation>
     </message>
     <message>
-        <location filename="../window_buttons.ui" line="42"/>
+        <location filename="window_buttons.ui" line="42"/>
         <source>Show flat buttons</source>
         <translation>Mostrar botones planos</translation>
     </message>
     <message>
-        <location filename="../window_buttons.ui" line="49"/>
+        <location filename="window_buttons.ui" line="49"/>
         <source>Show handle</source>
         <translation>Mostrar manijas</translation>
     </message>
     <message>
-        <location filename="../window_buttons.ui" line="56"/>
+        <location filename="window_buttons.ui" line="56"/>
         <source>Sorting Order:</source>
         <translation>Forma de ordenado:</translation>
     </message>
     <message>
-        <location filename="../window_buttons.ui" line="64"/>
+        <location filename="window_buttons.ui" line="64"/>
         <source>Timestamp</source>
         <translation>Marca de tiempo</translation>
     </message>
     <message>
-        <location filename="../window_buttons.ui" line="69"/>
+        <location filename="window_buttons.ui" line="69"/>
         <source>Group title and timestamp</source>
         <translation>Título del grupo y marca de tiempo</translation>
     </message>
     <message>
-        <location filename="../window_buttons.ui" line="74"/>
+        <location filename="window_buttons.ui" line="74"/>
         <source>Window Title</source>
         <translation>Título de la ventana</translation>
     </message>
     <message>
-        <location filename="../window_buttons.ui" line="79"/>
+        <location filename="window_buttons.ui" line="79"/>
         <source>Group title and window title</source>
         <translation>Título del grupo y título de la ventana</translation>
     </message>
     <message>
-        <location filename="../window_buttons.ui" line="84"/>
+        <location filename="window_buttons.ui" line="84"/>
         <source>None, allow drag-and-drop</source>
         <translation>Ninguno, permitir arrastrar y soltar</translation>
     </message>
     <message>
-        <location filename="../window_buttons.ui" line="92"/>
+        <location filename="window_buttons.ui" line="92"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Behavior&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Comportamiento&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="../window_buttons.ui" line="99"/>
+        <location filename="window_buttons.ui" line="99"/>
         <source>Window grouping:</source>
         <translation>Agrupar las ventanas:</translation>
     </message>
     <message>
-        <location filename="../window_buttons.ui" line="107"/>
+        <location filename="window_buttons.ui" line="107"/>
         <source>Never</source>
         <translation>Nunca</translation>
     </message>
     <message>
-        <location filename="../window_buttons.ui" line="112"/>
+        <location filename="window_buttons.ui" line="112"/>
         <source>Always</source>
         <translation>Siempre</translation>
     </message>
     <message>
-        <location filename="../window_buttons.ui" line="120"/>
+        <location filename="window_buttons.ui" line="120"/>
         <source>Middle click action:</source>
         <translation>Acción del clic de al medio:</translation>
     </message>
     <message>
-        <location filename="../window_buttons.ui" line="128"/>
+        <location filename="window_buttons.ui" line="128"/>
         <source>Nothing</source>
         <translation>Nada</translation>
     </message>
     <message>
-        <location filename="../window_buttons.ui" line="133"/>
+        <location filename="window_buttons.ui" line="133"/>
         <source>Close window</source>
         <translation>Cerrar ventana</translation>
     </message>
     <message>
-        <location filename="../window_buttons.ui" line="138"/>
+        <location filename="window_buttons.ui" line="138"/>
         <source>Minimize window</source>
         <translation>Minimizar ventana</translation>
     </message>
     <message>
-        <location filename="../window_buttons.ui" line="146"/>
+        <location filename="window_buttons.ui" line="146"/>
         <source>Restore minimized windows to current workspace</source>
         <translation>Restaurar ventanas minimizadas al área de trabajo activa</translation>
     </message>
     <message>
-        <location filename="../window_buttons.ui" line="153"/>
+        <location filename="window_buttons.ui" line="153"/>
         <source>Draw window frame when hovering over a button</source>
         <translation>Dibujar marco alrededor de la ventana al pasar por encima del botón</translation>
     </message>
     <message>
-        <location filename="../window_buttons.ui" line="160"/>
+        <location filename="window_buttons.ui" line="160"/>
         <source>Switch windows using the mouse wheel</source>
         <translation>intercambiar ventanas usando la rueda del ratón</translation>
     </message>
     <message>
-        <location filename="../window_buttons.ui" line="167"/>
+        <location filename="window_buttons.ui" line="167"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtering&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtraje&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="../window_buttons.ui" line="174"/>
+        <location filename="window_buttons.ui" line="174"/>
         <source>Show windows from all workspaces or viewports</source>
         <translation>Mostrar ventanas de todas las áreas de trabajo</translation>
     </message>
     <message>
-        <location filename="../window_buttons.ui" line="181"/>
+        <location filename="window_buttons.ui" line="181"/>
         <source>Show only minimized windows</source>
         <translation>Solo mostrar ventanas minimizadas</translation>
     </message>
     <message>
-        <location filename="../window_buttons.ui" line="188"/>
+        <location filename="window_buttons.ui" line="188"/>
         <source>Show windows from all monitors</source>
         <translation>Mostrar ventanas de todos los monitores</translation>
     </message>
     <message>
-        <location filename="../window_buttons.ui" line="238"/>
+        <location filename="window_buttons.ui" line="238"/>
         <source>Close</source>
         <translation>Cerrar</translation>
     </message>
@@ -564,84 +527,84 @@
 <context>
     <name>xfwm_compositor_settings</name>
     <message>
-        <location filename="../xfwm_compositor_settings.ui" line="14"/>
+        <location filename="xfwm_compositor_settings.ui" line="14"/>
         <source>Dialog</source>
         <translation>Diálogo</translation>
     </message>
     <message>
-        <location filename="../xfwm_compositor_settings.ui" line="42"/>
+        <location filename="xfwm_compositor_settings.ui" line="42"/>
         <source>Popup Windows</source>
         <translation>Ventanas desplegables</translation>
     </message>
     <message>
-        <location filename="../xfwm_compositor_settings.ui" line="49"/>
+        <location filename="xfwm_compositor_settings.ui" line="49"/>
         <source>Windows during move</source>
         <translation>Ventanas durante movida</translation>
     </message>
     <message>
-        <location filename="../xfwm_compositor_settings.ui" line="56"/>
+        <location filename="xfwm_compositor_settings.ui" line="56"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Opacity Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Ajustes de opacidad&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="../xfwm_compositor_settings.ui" line="79"/>
+        <location filename="xfwm_compositor_settings.ui" line="79"/>
         <source>Window decorations</source>
         <translation>Decoraciones de ventanas</translation>
     </message>
     <message>
-        <location filename="../xfwm_compositor_settings.ui" line="86"/>
+        <location filename="xfwm_compositor_settings.ui" line="86"/>
         <source>Show shadows under dock windows</source>
         <translation>Mostrar sombras debajo ventanas del muelle</translation>
     </message>
     <message>
-        <location filename="../xfwm_compositor_settings.ui" line="93"/>
+        <location filename="xfwm_compositor_settings.ui" line="93"/>
         <source>Show shadows under popup windows</source>
         <translation>Mostrar sombras debajo ventanas desplegables</translation>
     </message>
     <message>
-        <location filename="../xfwm_compositor_settings.ui" line="100"/>
+        <location filename="xfwm_compositor_settings.ui" line="100"/>
         <source>Windows during resize</source>
         <translation>Ventanas durante redimensionar</translation>
     </message>
     <message>
-        <location filename="../xfwm_compositor_settings.ui" line="123"/>
+        <location filename="xfwm_compositor_settings.ui" line="123"/>
         <source>Show shadows under regular windows</source>
         <translation>Mostrar sombras debajo ventanas normales</translation>
     </message>
     <message>
-        <location filename="../xfwm_compositor_settings.ui" line="130"/>
+        <location filename="xfwm_compositor_settings.ui" line="130"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Feature Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Ajustes de características&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="../xfwm_compositor_settings.ui" line="137"/>
+        <location filename="xfwm_compositor_settings.ui" line="137"/>
         <source>Show windows preview in place of icons when cycling</source>
         <translation>Mostrar visita previa en vez del icono cuando ciclando ventanas</translation>
     </message>
     <message>
-        <location filename="../xfwm_compositor_settings.ui" line="144"/>
+        <location filename="xfwm_compositor_settings.ui" line="144"/>
         <source>Display fullscreen overlay windows directly</source>
         <translation>Mostrar ventanas sobrepuestos directamente en pantalla plena</translation>
     </message>
     <message>
-        <location filename="../xfwm_compositor_settings.ui" line="183"/>
+        <location filename="xfwm_compositor_settings.ui" line="183"/>
         <source>Inactive windows</source>
         <translation>Ventanas inactivas</translation>
     </message>
     <message>
-        <location filename="../xfwm_compositor_settings.ui" line="190"/>
+        <location filename="xfwm_compositor_settings.ui" line="190"/>
         <source>Synchronize drawing to vertical blank</source>
         <translation>Sincronizar dibujando área vertical en blanco</translation>
     </message>
     <message>
-        <location filename="../xfwm_compositor_settings.ui" line="212"/>
+        <location filename="xfwm_compositor_settings.ui" line="212"/>
         <source>Close</source>
         <translation>Cerrar</translation>
     </message>
     <message>
-        <location filename="../xfwm_compositor_settings.cpp" line="38"/>
+        <location filename="xfwm_compositor_settings.cpp" line="38"/>
         <source>Xfwm Compositor Settings</source>
         <translation>Ajustes del Compositor de Xfwm</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
