@@ -1,562 +1,525 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="sk">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="sk" version="2.1">
 <context>
     <name>defaultlook</name>
     <message>
-        <location filename="../defaultlook.ui" line="20"/>
-        <location filename="../defaultlook.cpp" line="55"/>
-        <location filename="../defaultlook.cpp" line="467"/>
-        <location filename="../defaultlook.cpp" line="474"/>
-        <location filename="../defaultlook.cpp" line="491"/>
-        <location filename="../defaultlook.cpp" line="502"/>
-        <location filename="../defaultlook.cpp" line="512"/>
+        <location filename="defaultlook.ui" line="20"/>
+        <location filename="defaultlook.cpp" line="52"/>
+        <location filename="defaultlook.cpp" line="464"/>
+        <location filename="defaultlook.cpp" line="471"/>
+        <location filename="defaultlook.cpp" line="488"/>
+        <location filename="defaultlook.cpp" line="499"/>
+        <location filename="defaultlook.cpp" line="509"/>
         <source>MX Tweak</source>
         <translation>MX Tweak</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="54"/>
+        <location filename="defaultlook.ui" line="54"/>
         <source>Xfce Settings</source>
         <translation>Nastavenia Xfce</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="63"/>
+        <location filename="defaultlook.ui" line="63"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the panel&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Upraviť nastavenia panelu&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="77"/>
-        <location filename="../defaultlook.ui" line="283"/>
+        <location filename="defaultlook.ui" line="77"/>
+        <location filename="defaultlook.ui" line="283"/>
         <source>Panel</source>
         <translation>Panel</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="97"/>
+        <location filename="defaultlook.ui" line="97"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Configure window behavior and shortcuts&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Nastaviť správanie okien a odkazov na ploche&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="111"/>
+        <location filename="defaultlook.ui" line="111"/>
         <source>Window Manager</source>
         <translation>Správca okien</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="131"/>
+        <location filename="defaultlook.ui" line="131"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the look of your desktop&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Prispôsobiť vzhľad pracovnej plochy&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="145"/>
+        <location filename="defaultlook.ui" line="145"/>
         <source>Appearance</source>
         <translation>Vzhľad</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="223"/>
+        <location filename="defaultlook.ui" line="223"/>
         <source>About</source>
         <translation>O Programe</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="234"/>
+        <location filename="defaultlook.ui" line="234"/>
         <source>Help</source>
         <translation>Pomoc</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="251"/>
+        <location filename="defaultlook.ui" line="251"/>
         <source>Quit application</source>
         <translation>Zatvoriť aplikáciu</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="254"/>
+        <location filename="defaultlook.ui" line="254"/>
         <source>Close</source>
         <translation>Zavrieť</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="261"/>
+        <location filename="defaultlook.ui" line="261"/>
         <source>Alt+N</source>
         <translation>Alt+N</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="291"/>
+        <location filename="defaultlook.ui" line="291"/>
         <source>Options</source>
         <translation>Nastavenia</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="311"/>
+        <location filename="defaultlook.ui" line="311"/>
         <source>Backup current panel configuration</source>
         <translation>Zálohovať aktuálne nastavenie panelu</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="318"/>
+        <location filename="defaultlook.ui" line="318"/>
         <source>Restore backup panel configuration</source>
         <translation>Obnoviť uložené nastavenie panelu</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="325"/>
+        <location filename="defaultlook.ui" line="325"/>
         <source>Restore default panel</source>
         <translation>Obnoviť výrobné nastavenia</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="338"/>
+        <location filename="defaultlook.ui" line="338"/>
         <source>Affects 1st panel</source>
         <translation>Nastavuje 1. panel</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="345"/>
+        <location filename="defaultlook.ui" line="345"/>
         <source>Display panel vertically</source>
         <translation>Zobraz panel vertikálne</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="365"/>
+        <location filename="defaultlook.ui" line="359"/>
         <source>Bottom</source>
         <translation>Dolu</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="370"/>
+        <location filename="defaultlook.ui" line="364"/>
         <source>Top</source>
         <translation>Hore</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="378"/>
+        <location filename="defaultlook.ui" line="372"/>
         <source>Display panel horizontally</source>
         <translation>Zobraz panel horizontálne</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="398"/>
+        <location filename="defaultlook.ui" line="386"/>
         <source>Left</source>
         <translation>Vľavo</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="403"/>
+        <location filename="defaultlook.ui" line="391"/>
         <source>Right</source>
         <translation>Vpravo</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="411"/>
+        <location filename="defaultlook.ui" line="399"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Affects all panels&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Nastavuje všetky panely&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="431"/>
+        <location filename="defaultlook.ui" line="419"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Buttons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Tlačidlá okna&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="446"/>
-        <location filename="../defaultlook.ui" line="549"/>
-        <location filename="../defaultlook.ui" line="741"/>
-        <location filename="../defaultlook.ui" line="860"/>
-        <location filename="../defaultlook.ui" line="902"/>
+        <location filename="defaultlook.ui" line="434"/>
+        <location filename="defaultlook.ui" line="537"/>
+        <location filename="defaultlook.ui" line="707"/>
+        <location filename="defaultlook.ui" line="826"/>
+        <location filename="defaultlook.ui" line="868"/>
         <source>Apply</source>
         <translation>Použiť</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="469"/>
+        <location filename="defaultlook.ui" line="457"/>
         <source>Theme</source>
         <translation>Motív</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="483"/>
+        <location filename="defaultlook.ui" line="471"/>
         <source>Theme Options</source>
         <translation>Nastavenia Motívu</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="513"/>
+        <location filename="defaultlook.ui" line="501"/>
         <source>Fix some website fields when using dark theme</source>
         <translation>Opraviť polia na stránke pri použití tmavého motívu</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="516"/>
+        <location filename="defaultlook.ui" line="504"/>
         <source>Firefox dark theme tweak</source>
         <translation>Vyladenie tmavej témy Firefoxu </translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="523"/>
+        <location filename="defaultlook.ui" line="511"/>
         <source>Fix HexChat input box in dark theme</source>
         <translation>Opraviť vstupné pole HexChatu pri použití tmavého motívu</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="575"/>
+        <location filename="defaultlook.ui" line="563"/>
         <source>Undo</source>
         <translation>Vrátiť zmeny</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="582"/>
+        <location filename="defaultlook.ui" line="570"/>
         <source>Preview</source>
         <translation>Náhľad</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="589"/>
-        <source>Remove User Theme Sets</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../defaultlook.ui" line="600"/>
-        <source>Save Current Settings as a Theme Set</source>
-        <translation>Uložiť súčastné nastavenie ako užívateľskú Tému</translation>
-    </message>
-    <message>
-        <location filename="../defaultlook.ui" line="614"/>
-        <location filename="../defaultlook.ui" line="707"/>
+        <location filename="defaultlook.ui" line="580"/>
+        <location filename="defaultlook.ui" line="673"/>
         <source>Compositor</source>
         <translation>Kompozitor</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="635"/>
+        <location filename="defaultlook.ui" line="601"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor Settings&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Nastavenia Xfce Kompozitora&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="638"/>
+        <location filename="defaultlook.ui" line="604"/>
         <source>Xfwm Settings</source>
         <translation>Nastavenia Xfwm</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="662"/>
+        <location filename="defaultlook.ui" line="628"/>
         <source>None</source>
         <translation>Žiadny</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="667"/>
+        <location filename="defaultlook.ui" line="633"/>
         <source>Xfwm (Xfce) Compositor</source>
         <translation>Xfwm (Xfce) Kompozitor</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="672"/>
+        <location filename="defaultlook.ui" line="638"/>
         <source>Compton </source>
         <translation>Compton</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="680"/>
+        <location filename="defaultlook.ui" line="646"/>
         <source>Edit compton.conf directly in text editor</source>
         <translation>Upraviť compton.conf priamo v textovom editore</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="683"/>
+        <location filename="defaultlook.ui" line="649"/>
         <source>Edit compton.conf</source>
         <translation>Upraviť compton.conf</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="714"/>
+        <location filename="defaultlook.ui" line="680"/>
         <source>Transparency and shadow options</source>
         <translation>Možnosti priehľadnosti a tieňovania</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="721"/>
+        <location filename="defaultlook.ui" line="687"/>
         <source>Launch compton-conf configuration tool</source>
         <translation>Spustiť konfiguračný nástroj compton-conf</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="724"/>
+        <location filename="defaultlook.ui" line="690"/>
         <source>Compton settings</source>
         <translation>Compton nastavenia </translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="777"/>
+        <location filename="defaultlook.ui" line="743"/>
         <source>Config Options</source>
         <translation>Možnosti konfigurácie</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="785"/>
+        <location filename="defaultlook.ui" line="751"/>
         <source>Reset Lightdm (login screen) to system default theme</source>
         <translation>Obnoviť Lightdm (prihlasovaciu obrazovku) do východzieho nastavenia systému</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="792"/>
+        <location filename="defaultlook.ui" line="758"/>
         <source>Reset Thunar custom right-click actions to system defaults</source>
         <translation>Obnoviť akcie poklepaním myši v Thunar-e do východzieho nastavenia systému </translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="799"/>
+        <location filename="defaultlook.ui" line="765"/>
         <source>Use intel driver instead of default &quot;modsetting&quot; driver (requires restart)</source>
         <translation>Použiť ovládač intel namiesto predvoleného ovládača &quot;modsetting&quot;  (vyžaduje reštart)</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="806"/>
+        <location filename="defaultlook.ui" line="772"/>
         <source>          NOTE: existing /etc/X11/xorg.conf.d/20-intel.conf will be backed up to home folder</source>
         <translation>          POZOR: aktuálny konf. súbor /etc/X11/xorg.conf.d/20-intel.conf bude zazálohovaný v domovskej zložke </translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="813"/>
+        <location filename="defaultlook.ui" line="779"/>
         <source>Use tearfree amdgpu option</source>
         <translation>Použiť nastavenia amdgpu tearfree</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="820"/>
+        <location filename="defaultlook.ui" line="786"/>
         <source>          NOTE: existing /etc/X11/xorg.conf.d/20-amd.conf will be backed up to home folder</source>
         <translation>amd.conf bol zálohovaný v priečinku home</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="827"/>
+        <location filename="defaultlook.ui" line="793"/>
         <source>Use tearfree radeon driver option</source>
         <translation>Použiť tearfree nastavenia ovládača radeon</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="834"/>
+        <location filename="defaultlook.ui" line="800"/>
         <source>          NOTE: existing /etc/X11/xorg.conf.d/20-radeon.conf will be backed up to home folder</source>
         <translation>radeon.conf bol zálohovaný v priečinku home</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="874"/>
+        <location filename="defaultlook.ui" line="840"/>
         <source>Other</source>
         <translation>Iné</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="882"/>
+        <location filename="defaultlook.ui" line="848"/>
         <source>Enable single-click on desktop</source>
         <translation>Zapnúť spúšťanie jediným kliknutím na ploche</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="889"/>
+        <location filename="defaultlook.ui" line="855"/>
         <source>Enable single-click in Thunar File Manager</source>
         <translation>Zapnúť spúšťanie jediným kliknutím v Thunar-i</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="926"/>
+        <location filename="defaultlook.ui" line="892"/>
         <source>Show systray (notification area) frame</source>
         <translation>Zobraziť ohraničenie systray (oznamovacej oblasti)</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="933"/>
+        <location filename="defaultlook.ui" line="899"/>
         <source>Show windows from all workspaces in panel</source>
         <translation>Na paneli zobrazovať okná zo všetkých pracovných plôch</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="940"/>
+        <location filename="defaultlook.ui" line="906"/>
         <source>Enable mounting of internal drives by non-root users</source>
         <translation>Povoliť pripájanie interných diskov užívateľom bez práv root-a</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="947"/>
+        <location filename="defaultlook.ui" line="913"/>
         <source>Disable shortening of long filenames on the desktop</source>
         <translation>Zakázať skracovanie názvov súborov na ploche</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="954"/>
+        <location filename="defaultlook.ui" line="920"/>
         <source>Enable hibernate on Log Out menu </source>
         <translation>V Odhlasovacom okne zapnuť voľbu Hibernovať</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="961"/>
+        <location filename="defaultlook.ui" line="927"/>
         <source>                   note: to hibernate, swap needs to be &gt;= RAM</source>
         <translation>POZOR: Pre Hibernáciu je potrebný SWAP &gt;= RAM</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="466"/>
+        <location filename="defaultlook.cpp" line="463"/>
         <source>About MX Tweak</source>
         <translation>O programe MX Tweak</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="467"/>
+        <location filename="defaultlook.cpp" line="464"/>
         <source>Version: </source>
         <translation>Verzia:</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="468"/>
+        <location filename="defaultlook.cpp" line="465"/>
         <source>App for quick default ui theme changes and tweaks</source>
         <translation>Previesť rýchle zmeny v predvolených systémových motívoch</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="470"/>
+        <location filename="defaultlook.cpp" line="467"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Copyright (c) MX Linux</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="471"/>
-        <location filename="../defaultlook.cpp" line="474"/>
+        <location filename="defaultlook.cpp" line="468"/>
+        <location filename="defaultlook.cpp" line="471"/>
         <source>License</source>
         <translation>Licencia</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="472"/>
+        <location filename="defaultlook.cpp" line="469"/>
         <source>Cancel</source>
         <translation>Zrušiť</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="503"/>
+        <location filename="defaultlook.cpp" line="500"/>
         <source>Finished! Firefox may require a restart for changes to take effect</source>
         <translation>Dokončené! Pred zavedením zmien môže byť potrebné reštartovať Firefox</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="513"/>
+        <location filename="defaultlook.cpp" line="510"/>
         <source>This app is Xfce-only</source>
         <translation>Táto aplikácia je len pre Xfce</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="655"/>
+        <location filename="defaultlook.cpp" line="652"/>
         <source>Panel settings</source>
         <translation>Nastavenia panelu</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="656"/>
-        <source>Your current panel settings have been backed up in a hidden folder called .restore in your home folder (~/.restore/)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
+        <location filename="defaultlook.cpp" line="653"/>
         <source> Your current panel settings have been backed up in a hidden folder called .restore in your home folder (~/.restore/)</source>
-        <translation type="vanished">Nastavenia panelu boli zazálohované do skrytej zložky s názvom .restore vo vašej home zložke (~/.restore/)</translation>
+        <translation>Nastavenia panelu boli zazálohované do skrytej zložky s názvom .restore vo vašej home zložke (~/.restore/)</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="1073"/>
+        <location filename="defaultlook.cpp" line="1070"/>
         <source>Choose a theme set</source>
         <translation>Vybrať motív</translation>
     </message>
 </context>
-<context>
-    <name>remove_user_theme_set</name>
-    <message>
-        <location filename="../remove_user_theme_set.ui" line="14"/>
-        <source>Remove User Theme Set</source>
-        <translation>Odobrať užívateľskú tému</translation>
-    </message>
-</context>
-<context>
-    <name>theming_to_tweak</name>
-    <message>
-        <location filename="../theming_to_tweak.ui" line="14"/>
-        <source>Dialog</source>
-        <translation>Dialóg</translation>
-    </message>
-    <message>
-        <location filename="../theming_to_tweak.ui" line="20"/>
-        <source>Enter name for new theme set</source>
-        <translation>Zadajte meno novej sady tém</translation>
-    </message>
-</context>
 <context>
     <name>window_buttons</name>
     <message>
-        <location filename="../window_buttons.ui" line="14"/>
-        <location filename="../window_buttons.cpp" line="36"/>
+        <location filename="window_buttons.ui" line="14"/>
+        <location filename="window_buttons.cpp" line="36"/>
         <source>Window Buttons</source>
         <translation>Tlačidlá okna</translation>
     </message>
     <message>
-        <location filename="../window_buttons.ui" line="28"/>
+        <location filename="window_buttons.ui" line="28"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Appearance&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Vzhľad&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="../window_buttons.ui" line="35"/>
+        <location filename="window_buttons.ui" line="35"/>
         <source>Show button labels</source>
         <translation>Zobrazovať názvy tlačidiel</translation>
     </message>
     <message>
-        <location filename="../window_buttons.ui" line="42"/>
+        <location filename="window_buttons.ui" line="42"/>
         <source>Show flat buttons</source>
         <translation>Zobraziť ploché tlačidlá</translation>
     </message>
     <message>
-        <location filename="../window_buttons.ui" line="49"/>
+        <location filename="window_buttons.ui" line="49"/>
         <source>Show handle</source>
         <translation>Zobraziť uško</translation>
     </message>
     <message>
-        <location filename="../window_buttons.ui" line="56"/>
+        <location filename="window_buttons.ui" line="56"/>
         <source>Sorting Order:</source>
         <translation>Zoradenie</translation>
     </message>
     <message>
-        <location filename="../window_buttons.ui" line="64"/>
+        <location filename="window_buttons.ui" line="64"/>
         <source>Timestamp</source>
         <translation>Časová značka</translation>
     </message>
     <message>
-        <location filename="../window_buttons.ui" line="69"/>
+        <location filename="window_buttons.ui" line="69"/>
         <source>Group title and timestamp</source>
         <translation>Zoskupovať titulok a čas</translation>
     </message>
     <message>
-        <location filename="../window_buttons.ui" line="74"/>
+        <location filename="window_buttons.ui" line="74"/>
         <source>Window Title</source>
         <translation>Titulok okna</translation>
     </message>
     <message>
-        <location filename="../window_buttons.ui" line="79"/>
+        <location filename="window_buttons.ui" line="79"/>
         <source>Group title and window title</source>
         <translation>Zoskupovať titulok a titulok okna</translation>
     </message>
     <message>
-        <location filename="../window_buttons.ui" line="84"/>
+        <location filename="window_buttons.ui" line="84"/>
         <source>None, allow drag-and-drop</source>
         <translation>Žiadne, povoliť funkciu potiahni a pusť</translation>
     </message>
     <message>
-        <location filename="../window_buttons.ui" line="92"/>
+        <location filename="window_buttons.ui" line="92"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Behavior&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Správanie&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="../window_buttons.ui" line="99"/>
+        <location filename="window_buttons.ui" line="99"/>
         <source>Window grouping:</source>
         <translation>Zoskupovanie okien:</translation>
     </message>
     <message>
-        <location filename="../window_buttons.ui" line="107"/>
+        <location filename="window_buttons.ui" line="107"/>
         <source>Never</source>
         <translation>Nikdy</translation>
     </message>
     <message>
-        <location filename="../window_buttons.ui" line="112"/>
+        <location filename="window_buttons.ui" line="112"/>
         <source>Always</source>
         <translation>Vždy</translation>
     </message>
     <message>
-        <location filename="../window_buttons.ui" line="120"/>
+        <location filename="window_buttons.ui" line="120"/>
         <source>Middle click action:</source>
         <translation>Akcia stredného tlačidla:</translation>
     </message>
     <message>
-        <location filename="../window_buttons.ui" line="128"/>
+        <location filename="window_buttons.ui" line="128"/>
         <source>Nothing</source>
         <translation>Nič</translation>
     </message>
     <message>
-        <location filename="../window_buttons.ui" line="133"/>
+        <location filename="window_buttons.ui" line="133"/>
         <source>Close window</source>
         <translation>Zatvoriť okno</translation>
     </message>
     <message>
-        <location filename="../window_buttons.ui" line="138"/>
+        <location filename="window_buttons.ui" line="138"/>
         <source>Minimize window</source>
         <translation>Minimalizovať okno</translation>
     </message>
     <message>
-        <location filename="../window_buttons.ui" line="146"/>
+        <location filename="window_buttons.ui" line="146"/>
         <source>Restore minimized windows to current workspace</source>
         <translation>Obnoví minimalizované okná na tejto pracovnej ploche</translation>
     </message>
     <message>
-        <location filename="../window_buttons.ui" line="153"/>
+        <location filename="window_buttons.ui" line="153"/>
         <source>Draw window frame when hovering over a button</source>
         <translation>Vykresľovať rám okna pri umiestnení kurzora myši nad tlačidlo</translation>
     </message>
     <message>
-        <location filename="../window_buttons.ui" line="160"/>
+        <location filename="window_buttons.ui" line="160"/>
         <source>Switch windows using the mouse wheel</source>
         <translation>Prepínať okná kolieskom myši</translation>
     </message>
     <message>
-        <location filename="../window_buttons.ui" line="167"/>
+        <location filename="window_buttons.ui" line="167"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtering&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtrovanie&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="../window_buttons.ui" line="174"/>
+        <location filename="window_buttons.ui" line="174"/>
         <source>Show windows from all workspaces or viewports</source>
         <translation>Zobraziť okná zo všetkých pracovných plôch a zobrazovacích zariadení</translation>
     </message>
     <message>
-        <location filename="../window_buttons.ui" line="181"/>
+        <location filename="window_buttons.ui" line="181"/>
         <source>Show only minimized windows</source>
         <translation>Zobraziť iba minimalizované okná</translation>
     </message>
     <message>
-        <location filename="../window_buttons.ui" line="188"/>
+        <location filename="window_buttons.ui" line="188"/>
         <source>Show windows from all monitors</source>
         <translation>Zobraziť okná zo všetkých monitorov</translation>
     </message>
     <message>
-        <location filename="../window_buttons.ui" line="238"/>
+        <location filename="window_buttons.ui" line="238"/>
         <source>Close</source>
         <translation>Zatvoriť</translation>
     </message>
@@ -564,84 +527,84 @@
 <context>
     <name>xfwm_compositor_settings</name>
     <message>
-        <location filename="../xfwm_compositor_settings.ui" line="14"/>
+        <location filename="xfwm_compositor_settings.ui" line="14"/>
         <source>Dialog</source>
         <translation>Dialóg</translation>
     </message>
     <message>
-        <location filename="../xfwm_compositor_settings.ui" line="42"/>
+        <location filename="xfwm_compositor_settings.ui" line="42"/>
         <source>Popup Windows</source>
         <translation>Vyskakovacie Okná</translation>
     </message>
     <message>
-        <location filename="../xfwm_compositor_settings.ui" line="49"/>
+        <location filename="xfwm_compositor_settings.ui" line="49"/>
         <source>Windows during move</source>
         <translation>Okná pri presune</translation>
     </message>
     <message>
-        <location filename="../xfwm_compositor_settings.ui" line="56"/>
+        <location filename="xfwm_compositor_settings.ui" line="56"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Opacity Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Nastavenia Priehľadnosti&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="../xfwm_compositor_settings.ui" line="79"/>
+        <location filename="xfwm_compositor_settings.ui" line="79"/>
         <source>Window decorations</source>
         <translation>Dekorácie okien</translation>
     </message>
     <message>
-        <location filename="../xfwm_compositor_settings.ui" line="86"/>
+        <location filename="xfwm_compositor_settings.ui" line="86"/>
         <source>Show shadows under dock windows</source>
-        <translation>Zobraziť tieň pod dokovanými oknami&#xa0;</translation>
+        <translation>Zobraziť tieň pod dokovanými oknami </translation>
     </message>
     <message>
-        <location filename="../xfwm_compositor_settings.ui" line="93"/>
+        <location filename="xfwm_compositor_settings.ui" line="93"/>
         <source>Show shadows under popup windows</source>
         <translation>Zobraziť tieň pod vyskakovacími oknami</translation>
     </message>
     <message>
-        <location filename="../xfwm_compositor_settings.ui" line="100"/>
+        <location filename="xfwm_compositor_settings.ui" line="100"/>
         <source>Windows during resize</source>
         <translation>Okná pri zmene veľkosti</translation>
     </message>
     <message>
-        <location filename="../xfwm_compositor_settings.ui" line="123"/>
+        <location filename="xfwm_compositor_settings.ui" line="123"/>
         <source>Show shadows under regular windows</source>
         <translation>Zobraziť tieň pod bežnými oknami</translation>
     </message>
     <message>
-        <location filename="../xfwm_compositor_settings.ui" line="130"/>
+        <location filename="xfwm_compositor_settings.ui" line="130"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Feature Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Nastavenia Vzhľadu&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="../xfwm_compositor_settings.ui" line="137"/>
+        <location filename="xfwm_compositor_settings.ui" line="137"/>
         <source>Show windows preview in place of icons when cycling</source>
         <translation>Pri cyklovaní zobraziť náhľad okien v mieste ikon</translation>
     </message>
     <message>
-        <location filename="../xfwm_compositor_settings.ui" line="144"/>
+        <location filename="xfwm_compositor_settings.ui" line="144"/>
         <source>Display fullscreen overlay windows directly</source>
         <translation>Zobraziť fullscreen overlay okien okamžite</translation>
     </message>
     <message>
-        <location filename="../xfwm_compositor_settings.ui" line="183"/>
+        <location filename="xfwm_compositor_settings.ui" line="183"/>
         <source>Inactive windows</source>
         <translation>Neaktívne okná</translation>
     </message>
     <message>
-        <location filename="../xfwm_compositor_settings.ui" line="190"/>
+        <location filename="xfwm_compositor_settings.ui" line="190"/>
         <source>Synchronize drawing to vertical blank</source>
         <translation>Synchronizovať vykresľovanie s vertikálnou medzerou</translation>
     </message>
     <message>
-        <location filename="../xfwm_compositor_settings.ui" line="212"/>
+        <location filename="xfwm_compositor_settings.ui" line="212"/>
         <source>Close</source>
         <translation>Zavrieť</translation>
     </message>
     <message>
-        <location filename="../xfwm_compositor_settings.cpp" line="38"/>
+        <location filename="xfwm_compositor_settings.cpp" line="38"/>
         <source>Xfwm Compositor Settings</source>
         <translation>Nastavenia Xfwm kompozitora</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
